#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.footer.interfaces import IFooterTarget, IFooterRenderer, IFooterSettings, \
    IFooterRendererSettings
from pyams_default_theme.features.footer.interfaces import ISimpleFooterRendererSettings
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.footer.skin import BaseFooterRenderer
from pyams_default_theme.features.footer import SimpleFooterRendererSettings
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from pyams_default_theme import _


SIMPLE_FOOTER_RENDERER_NAME = 'PyAMS simple footer'


#
# Simple footer renderer
#

@adapter_config(name=SIMPLE_FOOTER_RENDERER_NAME, context=(IFooterTarget, IPyAMSLayer),
                provides=IFooterRenderer)
@adapter_config(name=SIMPLE_FOOTER_RENDERER_NAME, context=(IFooterSettings, IPyAMSLayer),
                provides=IFooterRenderer)
@template_config(template='templates/simple-footer.pt', layer=IPyAMSLayer)
class SimpleFooterRenderer(BaseFooterRenderer):
    """Simple footer renderer"""

    name = SIMPLE_FOOTER_RENDERER_NAME
    label = _("PyAMS simple footer with links")
    weight = 1

    settings_key = 'PyAMS::simple'
    settings_interface = ISimpleFooterRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)


@adapter_config(context=SimpleFooterRenderer, provides=IFooterRendererSettings)
def simple_footer_renderer_settings_factory(context):
    """Simple footer renderer settings factory"""
    return SimpleFooterRendererSettings()
